pub enum ClaimValidator {
Length {
min: Option<usize>,
max: Option<usize>,
},
Range {
min: Option<isize>,
max: Option<isize>,
},
Regex(Regex),
AnyOne(Vec<ClaimData>),
}Expand description
The validations that can be made to ClaimData
Variants
Length
The Hashed claim data length must be between min and max
min default is 0
max default is u64::MAX
Range
The Number claim data length must be between min and max
min default is i64::MIN
max default is i64::MAX
Regex(Regex)
The Hashed claim data must match this regular expression pattern
AnyOne(Vec<ClaimData>)
The claim data must be one of these
Implementations
Sourceimpl ClaimValidator
impl ClaimValidator
Sourcepub fn is_valid(&self, claim: &ClaimData) -> Option<bool>
pub fn is_valid(&self, claim: &ClaimData) -> Option<bool>
[Some(true)] if the claim is the right type and meets the validator requirements
[Some(false)] if the claim is the right type but doesn’t meet the requirements
None if the claim is the incorrect type
Sourcepub fn add_challenge_contribution(&self, transcript: &mut Transcript)
pub fn add_challenge_contribution(&self, transcript: &mut Transcript)
Add the public data to the transcript
Sourcepub fn regex_from_string(regex: &str) -> CredxResult<Self>
pub fn regex_from_string(regex: &str) -> CredxResult<Self>
Convert a regex into a validator