pub struct PublicKey {
pub w: G2Projective,
pub x: G2Projective,
pub y: Vec<G2Projective>,
pub y_blinds: Vec<G1Projective>,
}Expand description
The public key contains a generator point for each message that is signed and two extra. See section 4.2 in https://eprint.iacr.org/2015/525.pdf and https://eprint.iacr.org/2017/1197.pdf
w corresponds to m’ in the paper to achieve
EUF-CMA security level.
Fields
w: G2ProjectiveThe secret for m’
x: G2ProjectiveThe blinding secret
y: Vec<G2Projective>The secrets for each signed message
y_blinds: Vec<G1Projective>The secrets for each signed message for blinding purposes
Implementations
Sourceimpl PublicKey
impl PublicKey
Sourcepub fn is_invalid(&self) -> Choice
pub fn is_invalid(&self) -> Choice
Check if this public key is invalid
Sourcepub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn to_bytes(&self) -> Vec<u8> ⓘ
Store the public key as a sequence of bytes Each scalar is compressed to big-endian format Needs (N + 2) * P space otherwise it will panic where N is the number of messages that can be signed
Sourcepub fn from_bytes<B: AsRef<[u8]>>(bytes: B) -> Option<Self>
pub fn from_bytes<B: AsRef<[u8]>>(bytes: B) -> Option<Self>
Convert a byte sequence into the public key