Struct VerifiableEncryptionStatement

pub struct VerifiableEncryptionStatement<P: Group + GroupEncoding + Serialize + DeserializeOwned> {
    pub message_generator: P,
    pub encryption_key: PublicKey<Bls12381G2Impl>,
    pub id: String,
    pub reference_id: String,
    pub claim: usize,
}
Verifiable encryption

Use this statement when you know all the possible encrypted values and you want to prove that a specific value is one of them. To decrypt, you need to know the secret key and try all possible values until you find the one that matches the ciphertext.

Fields

message_generator: P

The generator for the message element

encryption_key: PublicKey<Bls12381G2Impl>

The encryption key for this ciphertext

id: String

The statement id

reference_id: String

The other statement id

claim: usize

The claim index in the other statement